@@ -102,14 +102,10 @@ paste_cite (GtkWidget *mi, GtkHTMLControlData *cd)
 static void
 insert_link (GtkWidget *mi, GtkHTMLControlData *cd)
 {
-	char *filename;
-
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	filename = g_build_filename (ICONDIR, "insert-link-24.png", NULL);
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Insert"), filename);
-	g_free (filename);
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Insert"), "stock_insert-url");
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_LINK, _("Link"),
@@ -192,8 +188,7 @@ show_prop_dialog (GtkHTMLControlData *cd, GtkHTMLEditPropertyType start)
 
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"),
-								     gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_properties", 16, NULL, NULL));
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), "gtk-properties");
 
 	cur = cd->properties_types;
 	while (cur) {
@@ -267,14 +262,10 @@ prop_dialog (GtkWidget *mi, GtkHTMLControlData *cd)
 static void
 link_prop_dialog (GtkWidget *mi, GtkHTMLControlData *cd)
 {
-	char *filename;
-
 	if (cd->properties_dialog)
 		gtk_html_edit_properties_dialog_close (cd->properties_dialog);
 
-	filename = g_build_filename (ICONDIR, "insert-link-24.png", NULL);
-	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), filename);
-	g_free (filename);
+	cd->properties_dialog = gtk_html_edit_properties_dialog_new (cd, _("Properties"), "stock_insert-url");
 
 	gtk_html_edit_properties_dialog_add_entry (cd->properties_dialog,
 						   GTK_HTML_EDIT_PROPERTY_LINK, _("Link"),
@@ -285,12 +276,6 @@ link_prop_dialog (GtkWidget *mi, GtkHTMLControlData *cd)
 	gtk_html_edit_properties_dialog_set_page (cd->properties_dialog, GTK_HTML_EDIT_PROPERTY_LINK);
 }
 
-static void
-spell_check_cb (GtkWidget *mi, GtkHTMLControlData *cd)
-{
-	spell_check_dialog (cd, FALSE);
-}
-
 static void
 replace_suggestion_cb (GtkWidget *mi, GtkHTMLControlData *cd)
 {
@@ -356,6 +341,10 @@ insert_html (GtkWidget *mi, GtkHTMLControlData *cd)
 		menuitem = gtk_menu_item_new_with_label (l); \
                 ADD_ITEM_BASE (f,t)
 
+#define ADD_ITEM_MNEMONIC(l,f,t) \
+		menuitem = gtk_menu_item_new_with_mnemonic (l); \
+		ADD_ITEM_BASE (f,t)
+
 #define ADD_STOCK(i,f) \
 		menuitem = gtk_image_menu_item_new_from_stock (i, NULL); \
                 ADD_ITEM_BASE (f,NONE);
@@ -454,7 +443,7 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 	ADD_STOCK_SENSITIVE (GTK_STOCK_CUT,  cut, active);
 	ADD_STOCK_SENSITIVE (GTK_STOCK_COPY, copy, active);
 	ADD_STOCK (GTK_STOCK_PASTE, paste);
-	ADD_ITEM (_("Paste Quotation"),  paste_cite, NONE);
+	ADD_ITEM_MNEMONIC (_("Paste _Quotation"),  paste_cite, NONE);
 
 	if (cd->format_html) {
 		ADD_SEP;
@@ -597,7 +586,7 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 	END_SUBMENU;
 
 	if (*items == 0) {
-		gtk_object_sink (GTK_OBJECT (menu));
+		g_object_ref_sink (menu);
 		menu = NULL;
 	} else
 		gtk_widget_show (menu);
@@ -654,7 +643,7 @@ property_dialog_show (GtkHTMLControlData *cd)
 	guint items, props;
 
 	menu = prepare_properties_and_menu (cd, &items, &props);
-	gtk_object_sink (GTK_OBJECT (menu));
+	g_object_ref_sink (menu);
 	if (props)
 		show_prop_dialog (cd, GTK_HTML_EDIT_PROPERTY_NONE);
 }
