@@ -25,14 +25,13 @@
 
 typedef struct _GtkHTMLSearchDialog  GtkHTMLSearchDialog;
 
-#include <gnome.h>
 #include "gtkhtml.h"
 #include "control-data.h"
 
 GtkHTMLSearchDialog * gtk_html_search_dialog_new     (GtkHTML *html, GtkHTMLControlData *cd);
 void                  gtk_html_search_dialog_destroy (GtkHTMLSearchDialog *d);
 
-void                  search                         (GtkHTMLControlData *cd, gboolean regular);
+void                  search                         (GtkHTMLControlData *cd);
 void                  search_next                    (GtkHTMLControlData *cd);
 
 #endif
